# Sashite

[![Build Status](https://travis-ci.org/sashite/sashite-ruby.svg?branch=master)][travis]
[![Gem Version](https://badge.fury.io/rb/sashite.svg)][gem]
[![Inline docs](http://inch-ci.org/github/sashite/sashite-ruby.svg?branch=master)][inchpages]
[![Documentation](http://img.shields.io/:yard-docs-38c800.svg)][rubydoc]

> A Ruby client for the [Sashite API](http://www.sashite.com/developer/).

Sashite provides a full API and an easy-to-use web interface so you can develop and play with a minimal amount of effort.

## Contact

* Home page: https://github.com/sashite/sashite-ruby
* Bugs/issues: https://github.com/sashite/sashite-ruby/issues
* Support: https://stackoverflow.com/questions/tagged/sashite

## Rubies

* [MRI](https://www.ruby-lang.org/)
* [Rubinius](http://rubini.us/)
* [JRuby](http://jruby.org/)

## Installation

__Sashite__ is cryptographically signed.

To be sure the gem you install hasn't been tampered with, add my public key (if you haven't already) as a trusted certificate:

    $ gem cert --add <(curl -Ls https://raw.github.com/sashite/sashite-ruby/master/certs/gem-sashite-public_cert.pem)
    $ gem install sashite -P HighSecurity

The `HighSecurity` trust profile will verify all gems.  All of __Sashite__'s dependencies are signed.

Or add this line to your application's Gemfile:

```ruby
gem 'sashite'
```

And then execute:

    $ bundle

## Usage

This library is a Ruby client you can use to interact with the Sashite API.

Here's a short example.

```ruby
require 'sashite'

client = Sashite::Client.new(token: 'YOUR_TOKEN')

# Fetch your user details
puts "My email is #{client.user.email}"
```

## Security

As a basic form of security __Sashite__ provides a set of SHA512 checksums for
every Gem release.  These checksums can be found in the `checksum/` directory.
Although these checksums do not prevent malicious users from tampering with a
built Gem they can be used for basic integrity verification purposes.

The checksum of a file can be checked using the `sha512sum` command.  For
example:

    $ sha512sum pkg/sashite-0.1.0.gem
    e9e35e1953104e2d428b0f217e418db3c1baecd9e011b2545f9fcba4ff7e3bba674c6b928b3d8db842a139cd7cc9806d77ebdc7f710ece4f2aecb343703e2451  pkg/sashite-0.1.0.gem

## Versioning

__Sashite__ follows [Semantic Versioning 2.0](http://semver.org/).

## Contributing

1. [Fork it](https://github.com/sashite/sashite-ruby/fork)
2. Create your feature branch (`git checkout -b my-new-feature`)
3. Commit your changes (`git commit -am 'Add some feature'`)
4. Push to the branch (`git push origin my-new-feature`)
5. Create a new Pull Request

## License

See `LICENSE.md` file.

[gem]: https://rubygems.org/gems/sashite
[travis]: https://travis-ci.org/sashite/sashite-ruby
[inchpages]: http://inch-ci.org/github/sashite/sashite-ruby/
[rubydoc]: http://rubydoc.info/gems/sashite/frames
